==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/impl/variant/PandaTypeProvider.java <==
package tocraft.walkers.impl.variant;

import net.minecraft.class_1299;
import net.minecraft.class_1440;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import tocraft.craftedcore.patched.TComponent;
import tocraft.walkers.api.variant.TypeProvider;

public class PandaTypeProvider extends TypeProvider<class_1440> {

    @Override
    public int getVariantData(class_1440 entity) {
        return entity.method_6525().method_6564();
    }

    @Override
    public class_1440 create(class_1299<class_1440> type, class_1937 level, int data) {
        class_1440 panda = new class_1440(type, level);
        panda.method_6529(class_1440.class_1443.method_6566(data));
        return panda;
    }

    @Override
    public int getFallbackData() {
        return class_1440.class_1443.field_6788.method_6564();
    }

    @Override
    public int getRange() {
        return class_1440.class_1443.values().length - 1;
    }

    @Override
    public class_2561 modifyText(class_1440 entity, class_5250 text) {
        class_1440.class_1443 gene = entity.method_6525();
        if (gene.equals(class_1440.class_1443.field_6788)) {
            return text;
        } else {
            //#if MC>1182
            String variantName = gene.getSerializedName();
            //#else
            //$$ String variantName = gene.getName();
            //#endif
            return TComponent.literal(formatTypePrefix(variantName) + " ").method_10852(text);
        }
    }
}

==> walkers-fabric-1.19.4-5.2-sources.jar: tocraft/walkers/impl/variant/PandaTypeProvider.java <==
package tocraft.walkers.impl.variant;

import net.minecraft.class_1299;
import net.minecraft.class_1440;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_5250;
import tocraft.craftedcore.patched.TComponent;
import tocraft.walkers.api.variant.TypeProvider;

public class PandaTypeProvider extends TypeProvider<class_1440> {

    @Override
    public int getVariantData(class_1440 entity) {
        return entity.method_6525().method_6564();
    }

    @Override
    public class_1440 create(class_1299<class_1440> type, class_1937 level, int data) {
        class_1440 panda = new class_1440(type, level);
        panda.method_6529(class_1440.class_1443.method_6566(data));
        return panda;
    }

    @Override
    public int getFallbackData() {
        return class_1440.class_1443.field_6788.method_6564();
    }

    @Override
    public int getRange() {
        return class_1440.class_1443.values().length - 1;
    }

    @Override
    public class_2561 modifyText(class_1440 entity, class_5250 text) {
        class_1440.class_1443 gene = entity.method_6525();
        if (gene.equals(class_1440.class_1443.field_6788)) {
            return text;
        } else {
            //#if MC>1182
            String variantName = gene.method_15434();
            //#else
            //$$ String variantName = gene.getName();
            //#endif
            return TComponent.literal(formatTypePrefix(variantName) + " ").method_10852(text);
        }
    }
}
